Struct tinyvg::decode::Decoder[][src]

pub struct Decoder<R> { /* fields omitted */ }
Used to perform the TinyVG parsing pass from an arbitrary std::io::Read.

let decoder = Decoder::new(File::open("data/shield.tvg").unwrap());

let image = decoder.decode().unwrap();

dbg!(image);

Implementations

Create a new decoder wrapping a std::io::Read

Decode a TinyVG image from the reader

let mut decoder = Decoder::new(File::open("data/shield.tvg").unwrap());

let image = decoder.decode().unwrap();

Decode a TinyVG image header file from the reader. Does not decode any commands from the file. To get commands, you must use Decoder::decode_commands after calling this function. Calling these two functions together is basically the same as calling Decoder::decode. This function exists so that you can attempt to render a file which failed parsing partway through its comands.

let mut decoder = Decoder::new(File::open("data/shield.tvg").unwrap());

let mut image = decoder.decode_header().unwrap();
decoder.decode_commands(&mut image).unwrap();

Decode TinyVG image commands from the reader. The Image can be obtained by calling Decoder::decode_header. Calling these two functions together is basically the same as calling Decoder::decode. This function exists so that you can attempt to render a file which failed parsing partway through its comands.

let mut decoder = Decoder::new(File::open("data/shield.tvg").unwrap());

let mut image = decoder.decode_header().unwrap();
decoder.decode_commands(&mut image).unwrap();